@@ -3,7 +3,7 @@ import os
 def make():
     print("Creating OS folders in need! This may take a few seconds or minutes!")
     os.system('git clone https://github.com/WWEMGamer2/OS-Folders.git')
-    os.system('cp ./OS-Folders/* ./*')
+    os.system('cp ./OS-Folders/* ./')
     os.system('rm -r ./OS-Folders')
     i = input('[./OS/config.py] What is your OS name? ')
     print("Formatting...")
